# Disable debug packages, we don't need them.
%global debug_package %{nil}

Name:		fedora-bbl
# The last part is short hash
Version:	2019.01.18.66c13fd
Release:	1%{?dist}
Summary:	Berkeley Boot Loader (BBL) with embedded Fedora kernel

License:	BSD
URL:		https://github.com/riscv/riscv-pk

# Download tarball, e.g.:
# https://github.com/riscv/riscv-pk/archive/%full_commit.tar.gz
%global full_commit 66c13fd4a9c1c2eda51df35ddc13e095469faec7
Source0:	https://github.com/riscv/riscv-pk/archive/%{full_commit}.tar.gz

BuildRequires:	systemd-udev
BuildRequires:	grubby-deprecated
BuildRequires:	gcc
BuildRequires:	binutils
BuildRequires:	findutils
BuildRequires:	grep
BuildRequires:	coreutils
BuildRequires:	kernel-core


%description
Berkeley Boot Loader (BBL) with embedded Fedora kernel (vmlinuz) image.
It is used for booting on RISC-V 64-bit (riscv64) systems.

%prep
%autosetup -n riscv-pk-%{full_commit}


%build
mkdir -p build
pushd build

# Find Fedora kernel image in /boot
vmlinuz=$(find /boot | grep vmlinuz | grep -v -E '(rescue|hmac)')
if [[ "$vmlinuz" = *$'\n'* ]]; then
  echo "We expected to find a single file!"
  exit 1
fi

echo "BBL payload: $vmlinuz"

../configure \
  --enable-logo \
  --with-payload=$vmlinuz

%make_build
popd


%install
pushd build
# Find Fedora kernel image in /boot and extract version
vmlinuz=$(find /boot | grep vmlinuz | grep -v -E '(rescue|hmac)')
vmlinuz_version=$(echo "$vmlinuz" | cut -d'-' -f2-)

mkdir -p %{buildroot}/boot
cp bbl %{buildroot}/boot/bbl-${vmlinuz_version}
popd


%files
%license LICENSE LICENSE.Batten LICENSE.riscv_logo.txt
%doc README.md
/boot/bbl-*

%changelog
* Fri Jan 18 2019 David Abdurachmanov <david.abdurachmanov@gmail.com> 2019.01.16.66c13fd-1
- Revert BLS (we use grubby-deprecated instead of grubby, same as ARMv7). This will be 
  needed for u-boot.
- Add systemd-udev and grubby to ensure that /boot is populated in chroot.

* Wed Jan 16 2019 David Abdurachmanov <david.abdurachmanov@gmail.com> 2019.01.16.66c13fd-2
- Introduce %post to move BBL into proper directory (/boot/machine_id/kernel_version/bbl)

* Wed Jan 16 2019 David Abdurachmanov <david.abdurachmanov@gmail.com> 2019.01.16.66c13fd-1
- Modify to follow: https://fedoraproject.org/wiki/Changes/BootLoaderSpecByDefault

* Tue Jan 15 2019 David Abdurachmanov <david.abdurachmanov@gmail.com> 2019.01.15.a02257a-1
- Rebuild for kernel-5.0.0-0.rc2.git0.1.0.riscv64.fc30

* Fri Dec 07 2018 David Abdurachmanov <david.abdurachmanov@gmail.com> 2018.12.07.92434c4-1
- Rebuild for kernel-4.20.0-0.rc5.git2.1.0.riscv64.fc30

* Tue Nov 27 2018 David Abdurachmanov <david.abdurachmanov@gmail.com> 2018.11.27.e125938-1
- Rebuild for kernel-4.20.0-0.rc4.git0.1.0.riscv64.fc29

* Wed Nov 21 2018 David Abdurachmanov <david.abdurachmanov@gmail.com> 2018.11.13.6ebd0f2-2
- Rebuild for kernel-4.20.0-0.rc3.git1.1.1.riscv64.fc29

* Tue Nov 13 2018 David Abdurachmanov <david.abdurachmanov@gmail.com> 2018.11.13.6ebd0f2-1
- Add new package
